( cd usr/include/libdv ; rm -rf dv1394.h )
( cd usr/include/libdv ; ln -sf dv.h dv1394.h )
( cd usr/lib ; rm -rf libdv.so.4 )
( cd usr/lib ; ln -sf libdv.so.4.0.3 libdv.so.4 )
( cd usr/lib ; rm -rf libdv.so )
( cd usr/lib ; ln -sf libdv.so.4.0.3 libdv.so )
